@@ -80,6 +80,11 @@ module GI.GObject.Structs.TypeClass
     typeClassPeekStatic                     ,
 
 
+-- ** ref #method:ref#
+
+    typeClassRef                            ,
+
+
 -- ** unref #method:unref#
 
 #if defined(ENABLE_OVERLOADING)
@@ -467,7 +472,7 @@ instance O.OverloadedMethodInfo TypeClassPeekParentMethodInfo TypeClass where
 --           , argDestroy = -1
 --           , argCallerAllocates = False
 --           , argCallbackUserData = False
---           , transfer = TransferEverything
+--           , transfer = TransferNothing
 --           }
 --       ]
 -- Lengths: []
@@ -729,6 +734,58 @@ typeClassPeekStatic type_ = liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 #endif
 
+-- method TypeClass::ref
+-- method type : MemberFunction
+-- Args: [ Arg
+--           { argCName = "type"
+--           , argType = TBasicType TGType
+--           , direction = DirectionIn
+--           , mayBeNull = False
+--           , argDoc =
+--               Documentation
+--                 { rawDocText = Just "type ID of a classed type"
+--                 , sinceVersion = Nothing
+--                 }
+--           , argScope = ScopeTypeInvalid
+--           , argClosure = -1
+--           , argDestroy = -1
+--           , argCallerAllocates = False
+--           , argCallbackUserData = False
+--           , transfer = TransferNothing
+--           }
+--       ]
+-- Lengths: []
+-- returnType: Just
+--               (TInterface Name { namespace = "GObject" , name = "TypeClass" })
+-- throws : False
+-- Skip return : False
+
+foreign import ccall "g_type_class_ref" g_type_class_ref :: 
+    CGType ->                               -- type : TBasicType TGType
+    IO (Ptr TypeClass)
+
+{-# DEPRECATED typeClassRef ["(Since version 2.84)","Use 'GI.GObject.Functions.typeClassGet' instead"] #-}
+-- | Increments the reference count of the class structure belonging to
+-- /@type@/.
+-- 
+-- This function will demand-create the class if it doesn\'t exist already.
+typeClassRef ::
+    (B.CallStack.HasCallStack, MonadIO m) =>
+    GType
+    -- ^ /@type@/: type ID of a classed type
+    -> m TypeClass
+    -- ^ __Returns:__ the t'GI.GObject.Structs.TypeClass.TypeClass'
+    --   structure for the given type ID
+typeClassRef type_ = liftIO $ do
+    let type_' = gtypeToCGType type_
+    result <- g_type_class_ref type_'
+    checkUnexpectedReturnNULL "typeClassRef" result
+    result' <- (newPtr TypeClass) result
+    return result'
+
+#if defined(ENABLE_OVERLOADING)
+#endif
+
 #if defined(ENABLE_OVERLOADING)
 type family ResolveTypeClassMethod (t :: Symbol) (o :: DK.Type) :: DK.Type where
     ResolveTypeClassMethod "addPrivate" o = TypeClassAddPrivateMethodInfo
