@@ -214,7 +214,7 @@ instance CallocPtr TypeInfo where
     boxedPtrCalloc = callocBytes 72
 
 
--- | Construct a `TypeInfo` struct initialized to zero.
+-- | Construct a t'TypeInfo' struct initialized to zero.
 newZeroTypeInfo :: MonadIO m => m TypeInfo
 newZeroTypeInfo = liftIO $ boxedPtrCalloc >>= wrapPtr TypeInfo
 
@@ -265,7 +265,7 @@ instance AttrInfo TypeInfoClassSizeFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeInfo.classSize"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeInfo.html#g:attr:classSize"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeInfo.html#g:attr:classSize"
         })
 
 typeInfo_classSize :: AttrLabelProxy "classSize"
@@ -327,7 +327,7 @@ instance AttrInfo TypeInfoBaseInitFieldInfo where
         GObject.Callbacks.mk_BaseInitFunc (GObject.Callbacks.wrap_BaseInitFunc Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeInfo.baseInit"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeInfo.html#g:attr:baseInit"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeInfo.html#g:attr:baseInit"
         })
 
 typeInfo_baseInit :: AttrLabelProxy "baseInit"
@@ -389,7 +389,7 @@ instance AttrInfo TypeInfoBaseFinalizeFieldInfo where
         GObject.Callbacks.mk_BaseFinalizeFunc (GObject.Callbacks.wrap_BaseFinalizeFunc Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeInfo.baseFinalize"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeInfo.html#g:attr:baseFinalize"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeInfo.html#g:attr:baseFinalize"
         })
 
 typeInfo_baseFinalize :: AttrLabelProxy "baseFinalize"
@@ -404,7 +404,7 @@ typeInfo_baseFinalize = AttrLabelProxy
 -- @
 -- 'Data.GI.Base.Attributes.get' typeInfo #classInit
 -- @
-getTypeInfoClassInit :: MonadIO m => TypeInfo -> m (Maybe GObject.Callbacks.ClassInitFunc_WithClosures)
+getTypeInfoClassInit :: MonadIO m => TypeInfo -> m (Maybe GObject.Callbacks.ClassInitFunc)
 getTypeInfoClassInit s = liftIO $ withManagedPtr s $ \ptr -> do
     val <- peek (ptr `plusPtr` 24) :: IO (FunPtr GObject.Callbacks.C_ClassInitFunc)
     result <- SP.convertFunPtrIfNonNull val $ \val' -> do
@@ -438,9 +438,9 @@ instance AttrInfo TypeInfoClassInitFieldInfo where
     type AttrBaseTypeConstraint TypeInfoClassInitFieldInfo = (~) TypeInfo
     type AttrAllowedOps TypeInfoClassInitFieldInfo = '[ 'AttrSet, 'AttrGet, 'AttrClear]
     type AttrSetTypeConstraint TypeInfoClassInitFieldInfo = (~) (FunPtr GObject.Callbacks.C_ClassInitFunc)
-    type AttrTransferTypeConstraint TypeInfoClassInitFieldInfo = (~)GObject.Callbacks.ClassInitFunc_WithClosures
+    type AttrTransferTypeConstraint TypeInfoClassInitFieldInfo = (~)GObject.Callbacks.ClassInitFunc
     type AttrTransferType TypeInfoClassInitFieldInfo = (FunPtr GObject.Callbacks.C_ClassInitFunc)
-    type AttrGetType TypeInfoClassInitFieldInfo = Maybe GObject.Callbacks.ClassInitFunc_WithClosures
+    type AttrGetType TypeInfoClassInitFieldInfo = Maybe GObject.Callbacks.ClassInitFunc
     type AttrLabel TypeInfoClassInitFieldInfo = "class_init"
     type AttrOrigin TypeInfoClassInitFieldInfo = TypeInfo
     attrGet = getTypeInfoClassInit
@@ -451,7 +451,7 @@ instance AttrInfo TypeInfoClassInitFieldInfo where
         GObject.Callbacks.mk_ClassInitFunc (GObject.Callbacks.wrap_ClassInitFunc Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeInfo.classInit"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeInfo.html#g:attr:classInit"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeInfo.html#g:attr:classInit"
         })
 
 typeInfo_classInit :: AttrLabelProxy "classInit"
@@ -466,7 +466,7 @@ typeInfo_classInit = AttrLabelProxy
 -- @
 -- 'Data.GI.Base.Attributes.get' typeInfo #classFinalize
 -- @
-getTypeInfoClassFinalize :: MonadIO m => TypeInfo -> m (Maybe GObject.Callbacks.ClassFinalizeFunc_WithClosures)
+getTypeInfoClassFinalize :: MonadIO m => TypeInfo -> m (Maybe GObject.Callbacks.ClassFinalizeFunc)
 getTypeInfoClassFinalize s = liftIO $ withManagedPtr s $ \ptr -> do
     val <- peek (ptr `plusPtr` 32) :: IO (FunPtr GObject.Callbacks.C_ClassFinalizeFunc)
     result <- SP.convertFunPtrIfNonNull val $ \val' -> do
@@ -500,9 +500,9 @@ instance AttrInfo TypeInfoClassFinalizeFieldInfo where
     type AttrBaseTypeConstraint TypeInfoClassFinalizeFieldInfo = (~) TypeInfo
     type AttrAllowedOps TypeInfoClassFinalizeFieldInfo = '[ 'AttrSet, 'AttrGet, 'AttrClear]
     type AttrSetTypeConstraint TypeInfoClassFinalizeFieldInfo = (~) (FunPtr GObject.Callbacks.C_ClassFinalizeFunc)
-    type AttrTransferTypeConstraint TypeInfoClassFinalizeFieldInfo = (~)GObject.Callbacks.ClassFinalizeFunc_WithClosures
+    type AttrTransferTypeConstraint TypeInfoClassFinalizeFieldInfo = (~)GObject.Callbacks.ClassFinalizeFunc
     type AttrTransferType TypeInfoClassFinalizeFieldInfo = (FunPtr GObject.Callbacks.C_ClassFinalizeFunc)
-    type AttrGetType TypeInfoClassFinalizeFieldInfo = Maybe GObject.Callbacks.ClassFinalizeFunc_WithClosures
+    type AttrGetType TypeInfoClassFinalizeFieldInfo = Maybe GObject.Callbacks.ClassFinalizeFunc
     type AttrLabel TypeInfoClassFinalizeFieldInfo = "class_finalize"
     type AttrOrigin TypeInfoClassFinalizeFieldInfo = TypeInfo
     attrGet = getTypeInfoClassFinalize
@@ -513,7 +513,7 @@ instance AttrInfo TypeInfoClassFinalizeFieldInfo where
         GObject.Callbacks.mk_ClassFinalizeFunc (GObject.Callbacks.wrap_ClassFinalizeFunc Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeInfo.classFinalize"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeInfo.html#g:attr:classFinalize"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeInfo.html#g:attr:classFinalize"
         })
 
 typeInfo_classFinalize :: AttrLabelProxy "classFinalize"
@@ -572,7 +572,7 @@ instance AttrInfo TypeInfoClassDataFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeInfo.classData"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeInfo.html#g:attr:classData"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeInfo.html#g:attr:classData"
         })
 
 typeInfo_classData :: AttrLabelProxy "classData"
@@ -621,7 +621,7 @@ instance AttrInfo TypeInfoInstanceSizeFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeInfo.instanceSize"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeInfo.html#g:attr:instanceSize"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeInfo.html#g:attr:instanceSize"
         })
 
 typeInfo_instanceSize :: AttrLabelProxy "instanceSize"
@@ -670,7 +670,7 @@ instance AttrInfo TypeInfoNPreallocsFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeInfo.nPreallocs"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeInfo.html#g:attr:nPreallocs"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeInfo.html#g:attr:nPreallocs"
         })
 
 typeInfo_nPreallocs :: AttrLabelProxy "nPreallocs"
@@ -732,7 +732,7 @@ instance AttrInfo TypeInfoInstanceInitFieldInfo where
         GObject.Callbacks.mk_InstanceInitFunc (GObject.Callbacks.wrap_InstanceInitFunc Nothing v)
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeInfo.instanceInit"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeInfo.html#g:attr:instanceInit"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeInfo.html#g:attr:instanceInit"
         })
 
 typeInfo_instanceInit :: AttrLabelProxy "instanceInit"
@@ -794,7 +794,7 @@ instance AttrInfo TypeInfoValueTableFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GObject.Structs.TypeInfo.valueTable"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.30/docs/GI-GObject-Structs-TypeInfo.html#g:attr:valueTable"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gobject-2.0.31/docs/GI-GObject-Structs-TypeInfo.html#g:attr:valueTable"
         })
 
 typeInfo_valueTable :: AttrLabelProxy "valueTable"
